import {RouteProp} from '@react-navigation/native';
import React, {useEffect, useRef} from 'react';
import {StatusBar, StyleSheet} from 'react-native';
import Orientation from 'react-native-orientation-locker';
import {SafeAreaView} from 'react-native-safe-area-context';
import {RootStackParamList} from '../App';
import DeckButton from '../components/DeckButton';

interface Props {
  remoteAddress: string;
  route: RouteProp<RootStackParamList, 'Deck'>;
}

export default function Deck(props: Props) {
  useEffect(() => {
    console.log('Lock to portait');
    Orientation.lockToPortrait();
    return () => {
      console.log('Unlock orientation');
      Orientation.unlockAllOrientations();
    };
  });

  const ws = useRef<WebSocket | null>(null);
  const remoteAddress = props.route.params.remoteAddress;
  useEffect(() => {
    console.log('Connect ws at: ' + remoteAddress);
    // TODO check if remote address is valid
    ws.current = new WebSocket(`ws://${remoteAddress}:8069/ws`);

    ws.current.onopen = () => {
      console.log('connectet ws');
    };
    ws.current.onerror = (e) => {
      // TODO tell the user something is wrong
      console.error(e.message);
    };

    return () => {
      console.log('close websocket');
      ws.current?.close();
    };
  });

  const buttons = [];

  for (let i = 0; i < 21; i++) {
    let text = 'btn' + i;
    buttons.push(
      <DeckButton
        text={text}
        key={i}
        onPress={() => {
          ws.current?.send(i + '');
        }}
      />,
    );
  }

  return (
    <>
      <StatusBar hidden={true} />
      <SafeAreaView style={style.view}>{buttons}</SafeAreaView>
    </>
  );
}

const style = StyleSheet.create({
  view: {
    flex: 1,
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
});
